import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_story/src/models/story.dart';
import 'package:ocg_story/src/repository/story.dart';

///
/// Events
///
abstract class StoryCreateEvent {}

class StoryCreateStartEvent extends StoryCreateEvent {
  final Story story;

  StoryCreateStartEvent(this.story);
}

abstract class StoryCreateState {}

class StoryCreateIdleState extends StoryCreateState {}

class StoryCreateLoadingState extends StoryCreateState {}

class StoryCreateSuccessState extends StoryCreateState {
  StoryCreateSuccessState();
}

class StoryCreateErrorState extends StoryCreateState {
  final String error;

  StoryCreateErrorState(this.error);
}

class StoryCreateBloc extends Bloc<StoryCreateEvent, StoryCreateState> {
  final StoryRepository storyRepository;
  StoryCreateBloc(this.storyRepository) : super(StoryCreateIdleState());

  @override
  Stream<StoryCreateState> mapEventToState(StoryCreateEvent event) async* {
    if (event is StoryCreateStartEvent) {
      yield StoryCreateLoadingState();
      AppResponse<bool> storiesResponse =
          await storyRepository.createStory(event.story);
      if (storiesResponse.isSuccess) {
        yield StoryCreateSuccessState();
      } else {
        yield StoryCreateErrorState(storiesResponse.error);
      }
    }
  }
}
