import 'dart:io';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:modal_progress_hud/modal_progress_hud.dart';
import 'package:ocg_app/ocg_app.dart';
import 'package:ocg_story/src/models/basic.dart';
import 'package:ocg_story/src/widgets/smiley_add_widget.dart';
import 'package:ocg_story/src/widgets/story_create_widget.dart';
import 'package:ocg_story/src/widgets/text_add_widget.dart';

class StoryImageCreateScreen extends StatefulWidget {
  final ImageData imageData;
  final Function(ImageData imageData) onCreate;
  final bool allowAdvanced;

  const StoryImageCreateScreen(
      {Key key,
      @required this.imageData,
      this.onCreate,
      this.allowAdvanced = false})
      : super(key: key);
  @override
  State<StatefulWidget> createState() => StoryImageCreateScreenState();
}

class StoryImageCreateScreenState extends State<StoryImageCreateScreen> {
  List<Basic> _children = [];
  final GlobalKey<ScaffoldState> _key = GlobalKey<ScaffoldState>();
  List<Widget> _stackChildren = [];
  StoryCreateController _controller;
  bool _isCreating;
  @override
  void initState() {
    super.initState();
    _children.add(widget.imageData);
    _isCreating = false;
    WidgetsBinding.instance.addPostFrameCallback((_) {
      _offset = Offset(MediaQuery.of(context).size.width / 2 - 32.0,
          MediaQuery.of(context).size.height - 150);
      setState(() {
        _stackChildren.add(
          StoryCreateWidget(
            children: _children,
            deleteOffset: _offset,
            onCompleted: (_controller) {
              this._controller = _controller;
            },
          ),
        );
        _stackChildren.add(_buildOptionsScreen());
      });
    });
  }

  Offset _offset;
  bool _adding = false;
  @override
  Widget build(BuildContext context) {
    if (_offset == null) {
      return Container();
    }
    List<Widget> widgets = [];
    widgets.addAll(_stackChildren);
    if (!_adding)
      widgets.add(Positioned(
          top: _offset.dy,
          left: _offset.dx,
          child: FloatingActionButton(
            onPressed: () {},
            child: Icon(
              Icons.delete_forever,
              color: Colors.black,
            ),
            backgroundColor: Colors.white,
          )));
    return AnnotatedRegion<SystemUiOverlayStyle>(
      value: SystemUiOverlayStyle.light,
      child: ModalProgressHUD(
        inAsyncCall: _isCreating,
        child: Scaffold(
          key: _key,
          backgroundColor: Colors.transparent,
          body: SafeArea(
            child: Stack(
              fit: StackFit.expand,
              children: widgets,
            ),
          ),
        ),
      ),
    );
  }

  Widget _buildButton(IconData iconData, Function onPressed) {
    return Padding(
      padding: const EdgeInsets.all(6.0),
      child: IconButton(
        onPressed: onPressed,
        color: Colors.black26,
        icon: Icon(
          iconData,
          color: Colors.white,
        ),
      ),
    );
  }

  Widget _buildOptionsScreen() {
    return Container(
        width: MediaQuery.of(context).size.width,
        height: MediaQuery.of(context).size.height,
        child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: <Widget>[
              Container(
                padding: EdgeInsets.all(4),
                decoration: BoxDecoration(color: Colors.black12, boxShadow: [
                  BoxShadow(
                      color: Colors.black12, blurRadius: 12, spreadRadius: 1)
                ]),
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: <Widget>[
                    IconButton(
                        icon: Icon(
                          Icons.clear,
                          color: Colors.white,
                        ),
                        onPressed: () {
                          Navigator.of(context).maybePop();
                        }),
                    Row(
                      mainAxisSize: MainAxisSize.min,
                      children: <Widget>[
                        widget.allowAdvanced
                            ? _buildButton(Icons.text_fields, () {
                                setState(() {
                                  _adding = true;
                                  _stackChildren.removeLast();
                                  _stackChildren.add(TextAddWidget(
                                    onSelected: _onSelected,
                                  ));
                                });
                              })
                            : Container(
                                width: 0,
                                height: 0,
                              ),
                        widget.allowAdvanced
                            ? _buildButton(Icons.tag_faces, () {
                                setState(() {
                                  _adding = true;
                                  _stackChildren.removeLast();
                                  _stackChildren.add(SmileyAddWidget(
                                    onSelected: _onSelected,
                                  ));
                                });
                              })
                            : Container(
                                width: 0,
                                height: 0,
                              ),
                        widget.onCreate != null
                            ? _buildButton(Icons.check, () async {
                                setState(() {
                                  _isCreating = true;
                                });
                                AppResponse<ImageData> imageData =
                                    await createStory();
                                _isCreating = false;
                                if (mounted) {
                                  setState(() {});
                                  if (imageData.isSuccess) {
                                    widget.onCreate(imageData.data);
                                  } else {
                                    debugPrint(
                                        "Error ${imageData.error.toString()}");
                                    _key.currentState.showSnackBar(SnackBar(
                                        content: Text("Some error occurred")));
                                  }
                                }
                              })
                            : Container(
                                width: 0,
                                height: 0,
                              ),
                      ],
                    )
                  ],
                ),
              ),
              Padding(
                  padding: const EdgeInsets.all(8.0),
                  child: Center(
                    child: Row(
                      crossAxisAlignment: CrossAxisAlignment.baseline,
                      textBaseline: TextBaseline.alphabetic,
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: <Widget>[
                        Container(),
                        // RaisedButton(
                        //   padding: EdgeInsets.all(16.0),
                        //   shape: RoundedRectangleBorder(
                        //       borderRadius: BorderRadius.circular(8.0)),
                        //   onPressed: () async {
                        //     AppResponse<ImageData> imageData =
                        //         await createStory();
                        //     Navigator.of(context).pop(imageData);
                        //   },
                        //   child: Row(
                        //     mainAxisSize: MainAxisSize.min,
                        //     children: <Widget>[
                        //       Padding(
                        //         padding: const EdgeInsets.only(right: 8.0),
                        //         child: Text(
                        //           "Your story",
                        //           style: TextStyle(
                        //               fontSize: 15.0,
                        //               color: Colors.black,
                        //               fontWeight: FontWeight.w500),
                        //         ),
                        //       ),
                        //       Icon(Icons.send)
                        //     ],
                        //   ),
                        //   color: Colors.white,
                        // ),
                      ],
                    ),
                  ))
            ]));
  }

  Future<AppResponse<ImageData>> createStory() async {
    if (_controller != null) {
      AppResponse<File> response = await _controller.createStory();
      if (response.isSuccess) {
        return AppResponse.named(
            data: ImageData.named(imagePath: response.data.path));
      } else {
        return AppResponse.named(error: "${response.error}");
      }
    } else {
      return AppResponse.named(error: "Controller not null");
    }
  }

  void _onSelected(Basic basic) {
    setState(() {
      _adding = false;
      if (basic != null) _children.add(basic);
      _stackChildren.clear();
      _stackChildren.add(
        StoryCreateWidget(
          deleteOffset: _offset,
          children: _children,
          onCompleted: (_controller) {
            this._controller = _controller;
          },
        ),
      );
      _stackChildren.add(_buildOptionsScreen());
    });
  }
}
