import 'dart:io';
import 'dart:ui';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:ocg_story/src/widgets/story_widget.dart';

class StoryImageWidget extends StatefulWidget {
  final String image;
  final Function() onLoaded;
  final StoryAssetType type;
  final Duration defaultDuration;
  const StoryImageWidget(
      {Key key,
      @required this.image,
      @required this.onLoaded,
      this.type = StoryAssetType.Network,
      this.defaultDuration})
      : super(key: key);

  @override
  State<StatefulWidget> createState() => _StoryImageWidgetState();
}

class _StoryImageWidgetState extends State<StoryImageWidget> {
  @override
  void initState() {
    super.initState();
  }

  @override
  void didChangeDependencies() {
    super.didChangeDependencies();
    if (widget.type != StoryAssetType.Network) widget.onLoaded();
  }

  Duration get duration => widget.defaultDuration ?? Duration(seconds: 2);

  @override
  Widget build(BuildContext context) {
    Widget image;
    if (widget.type == StoryAssetType.File) {
      image = Image.file(
        File(widget.image),
        width: MediaQuery.of(context).size.width,
        height: MediaQuery.of(context).size.height,
      );
    } else if (widget.type == StoryAssetType.Asset) {
      image = Image.asset(
        widget.image,
        width: MediaQuery.of(context).size.width,
        height: MediaQuery.of(context).size.height,
      );
    } else {
      image = Image.network(
        widget.image,
        gaplessPlayback: true,
        errorBuilder: (context, error, stackTrace) => Center(
          child: Icon(Icons.error),
        ),
        filterQuality: FilterQuality.high,
        loadingBuilder: (context, child, loadingProgress) {
          if (loadingProgress == null) {
            return Container();
          }
          double progress = loadingProgress.cumulativeBytesLoaded /
              loadingProgress.expectedTotalBytes;
          if (progress >= 0.99) {}
          return Center(
            child: CircularProgressIndicator(
              value: progress,
            ),
          );
        },
        width: MediaQuery.of(context).size.width,
        height: MediaQuery.of(context).size.height,
      );
    }
    return Container(
      width: MediaQuery.of(context).size.width,
      height: MediaQuery.of(context).size.height,
      child: image,
    );
  }
}
